Skip to contents

Set CS token to the environment.

Usage

set_token(token)

Arguments

token

token

Details

Given an CS token to access the CS database, store the token in the local environment. This means you don't need to pass the token to each call to the API. Moreover, you can set once and delete thus not have the token on display in R files.